@@ -1,9 +1,13 @@
 get_text_i <- function(txt, i) {
-	if (is.character(txt[[1]])) {
-		vapply(txt, "[[", character(1), i)
-	} else if (is.expression(txt[[1]])) {
-		sapply(txt, "[", i)
-	}
+	# if (is.character(txt[[1]])) {
+	# 	vapply(txt, "[[", character(1), i)
+	# } else if (is.expression(txt[[1]])) {
+	# 	sapply(txt, "[", i)
+	# }
+	lapply(txt, function(t) {
+		if (is.character(t)) t[[i]] else if (is.expression(t)) t[i]
+	})
+	#txt[[i]]
 }
 
 number_text_lines <- function(txt) {
