@@ -16,6 +16,10 @@
 	
 } 
 
+.onAttach <- function(libname, pkgname) {
+	packageStartupMessage("Breaking News: tmap 3.x is retiring. Please test v4, e.g. with\nremotes::install_github('r-tmap/tmap')")
+}
+
 .TMAP_CACHE <- new.env(FALSE, parent=globalenv())
 
 .crs_longlat <- sf::st_crs(4326)
