@@ -200,7 +200,7 @@ tmap_save <- function(tm=NULL, filename=NA, device=NULL, width=NA, height=NA, un
 
 	if (!is.arrange && !missing(insets_tm) && !missing(insets_vp)) {
 	  args_inset <- if (!is.na(scale)) list(scale = scale) else list()
-	  if (class(insets_tm)=="list" && class(insets_vp)=="list") {
+	  if (inherits(insets_tm, "list") && inherits(insets_vp, "list")) {
 	    if (length(insets_tm) != length(insets_vp)) stop("Number of insets unequal to number of viewports")
 	    mapply(function(tm_i, vp_i) {
 	      print(tm_i + do.call("tm_layout", args_inset), vp=vp_i)
