@@ -6,7 +6,7 @@ view_add_leaflet_titles <- function(lf) {
 			if (title!="") {
 				l$children[[1]] <- l$children[[1]] %>% htmlwidgets::onRender(paste("
 					function(el, x) {
-						var tldiv = document.getElementsByClassName(\"leaflet-top leaflet-left\")[",i,"];
+						var tldiv = el.getElementsByClassName(\"leaflet-top leaflet-left\")[0];
 						var titlediv = document.createElement('div');
 						titlediv.className = \"info legend leaflet-control\";
 						titlediv.innerHTML = \"<b>", title, "</b>\";
@@ -21,7 +21,7 @@ view_add_leaflet_titles <- function(lf) {
 		if (title!="") {
 			lf <- lf %>% htmlwidgets::onRender(paste("
 						function(el, x) {
-							var tldiv = document.getElementsByClassName(\"leaflet-top leaflet-left\")[0];
+							var tldiv = el.getElementsByClassName(\"leaflet-top leaflet-left\")[0];
 							var titlediv = document.createElement('div');
 							titlediv.className = \"info legend leaflet-control\";
 							titlediv.innerHTML = \"<b>", title, "</b>\";
